@@ -1,9 +1,11 @@
 from datetime import datetime
-from alert.exceptions import AlertIDAlreadyInUse, AlertBackendIDAlreadyInUse
+from alert.exceptions import AlertIDAlreadyInUse, AlertBackendIDAlreadyInUse,\
+    InvalidApplicableUsers
 from django.template.loader import render_to_string, find_template
 from django.contrib.sites.models import Site
 from django.template import TemplateDoesNotExist
 from django.contrib.auth.models import User
+from django.db import models
 
 ALERT_TYPES = {}
 ALERT_BACKENDS = {}
@@ -68,7 +70,10 @@ class BaseAlert(object):
         from alert.models import Alert
         
         users = self.get_applicable_users(**kwargs)
-        users = [users] if isinstance(users, User) else users
+        users = [users] if isinstance(users, models.Model) else users
+        
+        if len(users) and not isinstance(users[0], User):
+            raise InvalidApplicableUsers("%s.get_applicable_users() returned an invalid value. Acceptable values are a django.contrib.auth.models.User instance OR an iterable containing 0 or more User instances" % (self.id))
         
         site = Site.objects.get_current()
         
